<?php

namespace App\Http\Controllers;

use App\Models\Event;
use App\Models\Registration;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\EventResource;
use App\Http\Resources\RegistrationResource;

class EventController extends Controller
{
    public function index()
    {
        return EventResource::collection(Event::orderBy('created_at', 'desc')->get());
    }

    public function store(Request $request)
    {
        $event = Event::create($request->all());
        return new EventResource($event);
    }

    public function show($id)
    {
        $event = Event::findOrFail($id);

        $registrations = Registration::where('event_id', $id)->with('user')->get();

        return response()->json([
            'event' => new EventResource($event),
            'registrations' => RegistrationResource::collection($registrations),
        ]);
    }

    public function update(Request $request, $id)
    {
        $event = Event::findOrFail($id);
        $event->update($request->all());
        return new EventResource($event);
    }

    public function destroy($id)
    {
        $event = Event::findOrFail($id);
        $event->delete();
        return response()->json(null, 204);
    }

    public function statistics($eventId)
    {
        $totalUsers = Registration::where('event_id', $eventId)->count();
        $checkedInUsers = Registration::where('event_id', $eventId)->where('checked_in', true)->count();

        return response()->json([
            'total_users' => $totalUsers,
            'checked_in_users' => $checkedInUsers,
        ]);
    }

    public function registrations($eventId)
    {
        $registrations = Registration::where('event_id', $eventId)->with('user')->get();
        return RegistrationResource::collection($registrations);
    }
}
