<?php

namespace App\Http\Controllers;

use App\Models\Registration;
use App\Models\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\RegistrationResource;

class RegistrationController extends Controller
{
    public function index()
    {
        return RegistrationResource::collection(Registration::all());
    }

    public function store(Request $request)
    {
        // Validate the incoming request
        $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone' => 'required|string|max:20',
            'company' => 'nullable|string|max:255',
            'event_id' => 'required|exists:events,id',
        ]);

        $user = User::where('email', $request->email)
            ->orWhere('phone', $request->phone)->first();

        if (!$user) {
            $user = User::create([
                'name' => $request->first_name . ' ' . $request->last_name,
                'phone' => $request->phone,
                'email' => $request->email,
                'mobile_number' => $request->mobile_number,
                'company' => $request->company,
                'password' => '',
            ]);
        }

        $registration = Registration::create([
            'user_id' => $user->id,
            'event_id' => $request->event_id,
        ]);
        if (!$registration->relationLoaded('user')) {
            $registration->load('user');
        }

        return new RegistrationResource($registration);
    }

    public function show($id)
    {
        return new RegistrationResource(Registration::findOrFail($id));
    }


    public function destroy($id)
    {
        $registration = Registration::findOrFail($id);
        $registration->delete();
        return response()->json(null, 204);
    }

    public function update(Request $request, $id)
    {
        $registration = Registration::findOrFail($id);

        $registration->checked_in = true;

        $registration->save();

        if (!$registration->relationLoaded('user')) {
            $registration->load('user');
        }

        return new RegistrationResource($registration);
    }
}
